// Sharif Internet Contest 2008 (Nov 27 of 2008)
// A Soluton for Problem J (Juliet the water slider)
// Author: Saeed Seddighin
#include <cstdio>
#include <iostream>
#include <vector>
#include <cmath>
#include <complex>
#define double long double

using namespace std;

typedef complex<double> Point;

const double EPS=1e-6;

double x,y,v,w;
int n;

inline bool is_intersect(Point x1,Point y1,Point x2,Point y2,Point &ans){
  x2=(x2-x1)/(y1-x1);
  y2=(y2-x1)/(y1-x1);
  if (abs(x2.imag()-y2.imag()) < EPS) return(false);
  if (max(x2.imag(),y2.imag()) < -EPS) return(false);
  if (min(x2.imag(),y2.imag()) > EPS) return(false);

  ans=x2+(y2-x2)*(x2.imag()/(x2-y2).imag());
  ans=Point(max(ans.real(),(double)0.0),ans.imag());
  ans=Point(min(ans.real(),(double)1.0),ans.imag());
  ans=ans*(y1-x1)+x1;
  return(true);
}

pair<double,double> Rect(double x1,double y1,double x2,double y2){
  Point a(x1,y1),b(x1,y2),c(x2,y2),d(x2,y1);
  double Max=0,Min=abs(Point(x,y));
  Point temp;
  if (is_intersect(Point(0,0),Point(x,y),a,b,temp)){
    Min=min(Min,abs(temp));
    Max=max(Max,abs(temp));
  }

  if (is_intersect(Point(0,0),Point(x,y),b,c,temp)){
    Min=min(Min,abs(temp));
    Max=max(Max,abs(temp));
  }

  if (is_intersect(Point(0,0),Point(x,y),c,d,temp)){
    Min=min(Min,abs(temp));
    Max=max(Max,abs(temp));
  }

  if (is_intersect(Point(0,0),Point(x,y),d,a,temp)){
    Min=min(Min,abs(temp));
    Max=max(Max,abs(temp));
  }
  Max=max(Max,Min);
  return(pair<double,double>(Min,Max));
}

pair<double,double> Cir(double xcen,double ycen,double r){
  Point where(xcen,ycen);
  where/=Point(x,y);
  r/=abs(Point(x,y));
  if (abs(where.imag()) > r) return(pair<double,double>(0,0));
  double a=where.real()-sqrt(pow(r,2)-pow(where.imag(),2)),
         b=where.real()+sqrt(pow(r,2)-pow(where.imag(),2));
  a*=abs(Point(x,y));
  b*=abs(Point(x,y));
  return(pair<double,double>(a,b));
}

int main(){
  cout<<fixed;
  cout.precision(2);
  int ttime;
  cin>>ttime;
  for (int ccount=1;ccount<=ttime;ccount++){
    cin>>x>>y>>n>>v>>w;
    if (n > 10000) cerr<<"Bad input"<<endl;
    vector<pair<double,double> > all;
    for (int i=1;i<=n;i++){
      string a;
      cin>>a;
      if (a=="Circle"){
	double cenx,ceny,r;
	cin>>cenx>>ceny>>r;
	if (r < EPS) cerr<<"Bad r"<<endl;
	all.push_back(Cir(cenx,ceny,r));
      }else{
	if (a!="Rectangle") cerr<<"Bad rect"<<endl;
	double x1,x2,y1,y2;
	cin>>x1>>y1>>x2>>y2;
	if (abs(x1-x2) < EPS  || abs(y1-y2) < EPS) cerr<<"Bad rect"<<endl;
	if (x1 > x2) swap(x1,x2);
	if (y1 > y2) swap(y1,y2);
	all.push_back(Rect(x1,y1,x2,y2));
      }
    }
    sort(all.begin(),all.end());

    double last=0,sum=0,size=abs(Point(x,y));
    for (int i=0;i<all.size();i++){
      sum+=max((double)0.0,min(size,all[i].second)-max(last,all[i].first));
      last=max(last,all[i].second);
    }

    cout<<floor((sum/w+(size-sum)/v)*100)/100<<endl;
  }
}
